@@ -111,7 +111,7 @@ $lang = array_merge($lang, array(
 	'MAX_AVATAR_SIZE'				=> 'Avatarin maksimikoko',
 	'MAX_AVATAR_SIZE_EXPLAIN'		=> 'Leveys x korkeus pikseleinä',
 	'MAX_FILESIZE'					=> 'Avatar tiedoston maksimikoko',
-	'MAX_FILESIZE_EXPLAIN'			=> 'Palvelimelle siirrettyjä Avatar tiedostoja varten',
+	'MAX_FILESIZE_EXPLAIN'			=> 'Palvelimelle siirrettyjä Avatar tiedostoja varten. Nolla tarkoittaa rajoittamatonta kokoa tässä ohjelmassa, mutta palvelimen PHP-asetukset asettavat silti omat rajoituksensa tiedoston koolle.',
 	'MIN_AVATAR_SIZE'				=> 'Avatar tiedoston minimikoko',
 	'MIN_AVATAR_SIZE_EXPLAIN'		=> 'Leveys x korkeus pikseleinä',
 ));
