@@ -401,7 +401,7 @@ $lang = array_merge($lang, array(
 	'INACTIVE_REASON_UNKNOWN'		=> 'Tuntematon',
 	'INACTIVE_USERS'				=> 'Vahvistamattomat käyttäjät',
 	'INACTIVE_USERS_EXPLAIN'		=> 'Tässä on lista juuri rekisteröityneistä käyttäjistä, joiden käyttäjätunnukset vaativat vielä vahvistuksen. Voit halutessasi aktivoida, poistaa tai muistuttaa käyttäjää (lähettämällä sähköpostia).',
-	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'Tässä listassa on kymmenen viimeisintä käyttäjää, joiden tunnukset ovat suljetut. Voit katsoa koko listan menemällä oikeaan paikkaan hallinnassa tai klikkaamalla alapuolella olevaa linkkiä. Voit halutessasi aktivoida, poistaa tai muistuttaa käyttäjää (lähettämällä sähköpostia).',
+	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'Tässä listassa on kymmenen uusinta käyttäjää, joiden tunnukset ovat suljetut. Käyttäjätunnukset ovat suljetut, koska rekisteröitymisen asetuksissa on asetettu tunnusten aktivointi päälle tai käyttäjätunnus on suljettu ylläpitäjien toimesta. Alapuolella on linkki täyteen listaan ja sivulle, josta voit lähettää muistutuksen käyttäjille aktivoinnista tai poistaa tunnukset.',
 
 	'NO_INACTIVE_USERS'	=> 'Ei vahvistamattomia käyttäjiä',
 
