@@ -1,7 +1,7 @@
 <?php
 /** 
 *
-* acp_permissions [Finnish]
+* acp_permissions [Finnish [Fin]]
 *
 * @package language
 * @copyright (c) 2006 phpBB Group 
@@ -83,13 +83,13 @@ $lang = array_merge($lang, array(
 	'ACP_FORUM_PERMISSIONS_COPY_EXPLAIN'		=> 'Täällä voit kopioida oikeuksia yhdelle tai useammalle alueelle.',
 	'ACP_GLOBAL_MODERATORS_EXPLAIN'				=> 'Täällä voit antaa yleisvalvojan oikeudet käyttäjälle tai ryhmälle. Yleisvalvojat ovat muuten samanlaisia, kuin tavalliset valvojat, mutta heidän oikeudet ovat voimassa jokaisella alueella.',
 	'ACP_GROUPS_FORUM_PERMISSIONS_EXPLAIN'		=> 'Täällä voit antaa foorumin oikeuksia ryhmille.',
-	'ACP_GROUPS_PERMISSIONS_EXPLAIN'			=> 'Täällä voit asettaa yleisiä oikeuksia käyttäjäryhmille - käyttäjän oikeudet, yleiset valvojan oikeudet, ja ylläpitäjän oikeudet. Käyttäjän oikeuksiin kuuluu asetuksia, kuten avatar-kuvan käyttö ja yksityisviestien lähettäminen. Yleiset valvojan asetukset, kuten viestien hyväksyminen, viestiketjujen hallinta, porttikiellot ja viimeisenä ylläpitäjän oikeudet, kuten mukautettujen BBCode tagien luonti ja foorumeiden hallinta. Yksittäisiä käyttäjän oikeuksia tulisi muokata vain harvoin. Suositeltava tapa on lisätä käyttäjä ryhmään, jolle on annettu oikeudet toiminnon suorittamiseen.',
+	'ACP_GROUPS_PERMISSIONS_EXPLAIN'			=> 'Täällä voit laittaa yleiset oikeudet ryhmille - käyttäjän oikeudet, yleiset valvojan- ja ylläpitäjän oikeudet. Käyttäjän oikeuksiin liittyvät asiat kuten avatarin käyttö, yksityisviestit, jne.. Yleisiin valvojan oikeuksiin liittyvät viestien hyväksyminen, viestiketjujen hallinta, porttikieltojen hallinta, jne... Ylläpitäjän oikeuksiin liittyvät oikeuksien hallinta, mukautetut BB-koodit, alueiden hallinta, jne... Käyttäjäkohtaisia oikeuksia ei pitäisi muuttaa koskaan suoraan. Kannattaa aina muokata oikeuksia käyttäjäryhmän kautta ja asettaa käyttäjät näihin ryhmiin.',
 	'ACP_ADMIN_ROLES_EXPLAIN'					=> 'Täällä voit hallita ylläpitäjän roolin oikeuksia. Roolit ovat voimassaolevia oikeuksia, Mikäli muokkaat roolia. Kohteet joilla tämä rooli on käytössä muuttavat myös näiden oikeuksia.',
 	'ACP_FORUM_ROLES_EXPLAIN'					=> 'Täällä voit hallita alueen oikeuksien rooleja. Roolit ovat voimassaolevia oikeuksia, Mikäli muokkaat roolia. Kohteet joilla tämä rooli on käytössä muuttavat myös näiden oikeuksia.',
 	'ACP_MOD_ROLES_EXPLAIN'						=> 'Täällä voit hallita valvojien oikeuksien rooleja. Roolit ovat voimassaolevia oikeuksia, Mikäli muokkaat roolia. Kohteet joilla tämä rooli on käytössä muuttavat myös näiden oikeuksia.',
 	'ACP_USER_ROLES_EXPLAIN'					=> 'Täällä voit hallita käyttäjän oikeuksien rooleja. Roolit ovat voimassaolevia oikeuksia, Mikäli muokkaat roolia. Kohteet joilla tämä rooli on käytössä muuttavat myös näiden oikeuksia.',
 	'ACP_USERS_FORUM_PERMISSIONS_EXPLAIN'		=> 'Täällä voit liittää keskustelualueen oikeuksia käyttäjille.',
-	'ACP_USERS_PERMISSIONS_EXPLAIN'				=> 'Täällä voit liittää yleisiä oikeuksia käyttäjille - käyttäjän oikeudet, yleisvalvojan tai ylläpitäjän oikeudet. Käyttäjän oikeudet sallivat tiettyjä toimintoja, kuten avatar-kuvan käyttämisen, yksityisviestien lähettämisen, jne. Yleisvalvojan oikeuksia, kuten viestien hyväksyminen, viestiketjujen hallinta, porttikieltojen hallinta, jne ja viimeisenä ylläpitäjän asetukset, kuten oikeuksien määrittely, mukautetun BBCoden luominen, alueiden hallinta, jne. Sinun kannattaa käyttää ryhmän oikeuksien hallintaa muokataksesi useampaa käyttäjää kerralla. Käyttäjän henkilökohtaisia asetuksia tarvitsee muuttaa vain tietyissä tapauksissa. Suositeltava tapa on lisätä käyttäjä ryhmään ja antaa ryhmälle oikeuksia.',
+	'ACP_USERS_PERMISSIONS_EXPLAIN'				=> 'Täällä voit laittaa yleiset oikeudet käyttäjille - käyttäjän oikeudet, yleiset valvojan- ja ylläpitäjän oikeudet. Käyttäjän oikeuksiin liittyvät asiat kuten avatarin käyttö, yksityisviestit, jne.. Yleisiin valvojan oikeuksiin liittyvät viestien hyväksyminen, viestiketjujen hallinta, porttikieltojen hallinta, jne... Ylläpitäjän oikeuksiin liittyvät oikeuksien hallinta, mukautetut BB-koodit, alueiden hallinta, jne... Oikeuksien muokkaaminen usealle käyttäjälle kerralla on helppoa käyttäjäryhmien kautta. Käyttäjien henkilökohtaisia oikeuksia ei yleensä tarvitse muuttaa suoraan.',
 	'ACP_VIEW_ADMIN_PERMISSIONS_EXPLAIN'		=> 'Täällä voit katsoa ylläpitäjän oikeuksia käyttäjälle tai ryhmälle.',
 	'ACP_VIEW_GLOBAL_MOD_PERMISSIONS_EXPLAIN'	=> 'Täällä voit katsoa yleivalvojan oikeuksia valitsemillesi käytäjille tai ryhmille.',
 	'ACP_VIEW_FORUM_PERMISSIONS_EXPLAIN'		=> 'Täällä voit katsoa keskustelualueen oikeuksia tietyille käyttäjille tai ryhmille.',
@@ -170,7 +170,7 @@ $lang = array_merge($lang, array(
 	'ROLE_FORUM_POLLS'			=> 'Normaali pääsy + äänestykset',
 	'ROLE_FORUM_READONLY'		=> 'Vain luku',
 	'ROLE_FORUM_STANDARD'		=> 'Normaali pääsy',
-	'ROLE_FORUM_NEW_MEMBER'		=> 'Uusi käyttäjä',
+	'ROLE_FORUM_NEW_MEMBER'		=> 'Uuden käyttäjän oikeudet',
 	'ROLE_MOD_FULL'				=> 'Täysi valvoja',
 	'ROLE_MOD_QUEUE'			=> 'Jonon valvoja',
 	'ROLE_MOD_SIMPLE'			=> 'Yksinkertainen valvoja',
@@ -180,7 +180,7 @@ $lang = array_merge($lang, array(
 	'ROLE_USER_NOAVATAR'		=> 'Ei avataria',
 	'ROLE_USER_NOPM'			=> 'Ei yksityisviestejä',
 	'ROLE_USER_STANDARD'		=> 'Normaalit toiminnot',
-	'ROLE_USER_NEW_MEMBER'		=> 'Uusi käyttäjä',
+	'ROLE_USER_NEW_MEMBER'		=> 'Uuden käyttäjän toiminnot',
 
 	'ROLE_DESCRIPTION_ADMIN_FORUM'		=> 'Pääsee muuttamaan alueen hallinnan ja oikeuden asetuksia.',
 	'ROLE_DESCRIPTION_ADMIN_FULL'		=> 'Saa täydelliset oikeudet keskustelufoorumin ylläpitämiseen.<br />Ei suositeltava toimenpide.',
