@@ -191,7 +191,7 @@ $lang = array_merge($lang, array(
 	'FORM_INVALID'			=> 'Lähetämäsi lomake oli epäkelpo. Yritä lähettää lomake uudelleen.',
 	'FORUM'					=> 'Keskustelualue',
 	'FORUMS'				=> 'Keskustelualueet',
-	'FORUMS_MARKED'			=> 'Valitsemasi alue on merkitty luetuksi',
+	'FORUMS_MARKED'			=> 'Alueet ovat merkitty luetuksi',
 	'FORUM_CAT'				=> 'Kategoria',
 	'FORUM_INDEX'			=> 'Etusivu',
 	'FORUM_LINK'			=> 'Linkitetty alue',
@@ -451,6 +451,7 @@ $lang = array_merge($lang, array(
 	'POST_TIME'				=> 'Päiväys',
 	'POST_TOPIC'			=> 'Lähetä uusi viesti',
 	'POST_UNAPPROVED'		=> 'Tämä viesti odottaa hyväksyntää',
+	'POWERED_BY'			=> 'Keskustelufoorumin moottorina toimii %s',
 	'PREVIEW'				=> 'Esikatselu',
 	'PREVIOUS'				=> 'Edellinen',
 	'PREVIOUS_STEP'			=> 'Edellinen',
@@ -459,6 +460,7 @@ $lang = array_merge($lang, array(
 	'PRIVATE_MESSAGES'		=> 'Yksityisviestejä',
 	'PRIVATE_MESSAGING'		=> 'Yksityisviestin lähetys',
 	'PROFILE'				=> 'Omat asetukset',
+	'RANK'					=> 'Arvonimi',
 
 	'READING_FORUM'				=> 'Lukee keskustelualuetta %s',
 	'READING_GLOBAL_ANNOUNCE'	=> 'Lukee yleistiedotetta',
