@@ -53,7 +53,7 @@ $lang = array_merge($lang, array(
 	'JUMP_TO_POST'			=> 'Hyppää viestiin',
 
 	'LOGIN_EXPLAIN_EGOSEARCH'			=> 'Kirjaudu sisään katsoaksesi omia viestejäsi.',
-	'LOGIN_EXPLAIN_UNREADSEARCH'		=> 'Kirjaudu siään katsoaksesi lukemattomia viestejäsi.',
+	'LOGIN_EXPLAIN_UNREADSEARCH'		=> 'Kirjaudu sisään katsoaksesi lukemattomia viestejäsi.',
     'LOGIN_EXPLAIN_NEWPOSTS'			=> 'Kirjaudu sisään katsoaksesi edellisen käynnin jälkeen tulleita viestejä.',
 	'MAX_NUM_SEARCH_KEYWORDS_REFINE'	=> 'Annoit liian monta hakusanaa. Voit etsiä vain %1$d sanaa.',
 
