@@ -137,7 +137,8 @@ $lang = array_merge($lang, array(
 	'CREATE_FOLDER'				=> 'Lisää kansio...',
 	'CURRENT_IMAGE'				=> 'Nykyinen kuva',
 	'CURRENT_PASSWORD'			=> 'Nykyinen salasana',
-	'CURRENT_PASSWORD_EXPLAIN'	=> 'Vahvista sähköpostiosoitteen ja käyttäjätunnuksen vaihto antamalla salasanasi.',
+	'CURRENT_PASSWORD_EXPLAIN'	=> 'Laita nykyinen salasanasi, jos haluat muuttaa käyttäjätunnustasi tai sähköpostiosoitettasi.',
+	'CURRENT_CHANGE_PASSWORD_EXPLAIN' => 'Tietojen muuttaminen vahvistetaan nykyisellä salasanallasi.',
 	'CUR_PASSWORD_EMPTY'		=> 'Et antanut nykyistä salasanaasi.',
 	'CUR_PASSWORD_ERROR'		=> 'Antamasi salasana on virheellinen.',
 	'CUSTOM_DATEFORMAT'			=> 'Mukautettu...',
@@ -387,6 +388,7 @@ $lang = array_merge($lang, array(
 	'RULE_ADDED'						=> 'Sääntö lisätty',
 	'RULE_ALREADY_DEFINED'				=> 'Tämä sääntö on jo määritelty',
 	'RULE_DELETED'						=> 'sääntö poistettu',
+	'RULE_LIMIT_REACHED'				=> 'Et voi luoda uutta YV-sääntöä. Sinulla on jo maksimimäärä sääntöjä käytössä.',
 	'RULE_NOT_DEFINED'					=> 'Sääntöä ei ole määritelty oikein',
 	'RULE_REMOVED_MESSAGE'				=> 'Yksityisviestien suodattimet ovat poistaneet yhden viestin.',
 	'RULE_REMOVED_MESSAGES'				=> 'Yksityisviestien suodattimet ovat poistaneet %d viestiä.',
